.. e(BE:L) documentation master file, created by
   sphinx-quickstart on Fri Sep  4 13:35:41 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cli
   odb
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
